<p style="text-align:center;"><img src="logo.png" alt="Logo"></p>

Standing for *Yet Underused Path Instruments*, **yupi** is a set of tools designed
for collecting, generating and processing trajectory data.

## Installation

Current recommended installation method is via the pypi package:

```cmd
pip install yupi
```

## Getting Started

In the [official documentation](https://yupi.readthedocs.io/en/latest/) there
are some resources to start using the library: Tutorials, Examples  and a
detailed description of the API.

## Examples

Code examples (with additional multimedia resources) can be found in
[this repository](https://github.com/yupidevs/yupi_examples). Additionally, in
the [Examples section](https://yupi.readthedocs.io/en/latest/examples/examples.html)
of the documentation, you can find the same examples with additional comments
and expected execution results in order to inspect the examples without actually
executing them.
